# Generated by Django 4.1.7 on 2023-03-27 19:29

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ('users', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='appuser',
            name='created',
            field=models.DateTimeField(auto_now_add=True, verbose_name='created'),
        ),
    ]
